{% extends "wagtailadmin/login.html" %}
{% load wagtailadmin_tags i18n %}
{% block titletag %}{% trans "Sign in" %}{% endblock %}
{% block bodyclass %}login{% endblock %}

{% block fields %}
    {% formattedfield form.username %}

    {% block extra_fields %}
        {% for field_name, field in form.extra_fields %}
            {% formattedfield field %}
        {% endfor %}
    {% endblock extra_fields %}

    {% include "wagtailadmin/shared/forms/single_checkbox.html" with label_classname="remember-me" name="remember" text=_("Remember me") %}
{% endblock %}

{% block extra_js %}
{{ block.super }}
<script>
    $(function(){
        $('form input[name=email]').trigger('focus');
    })
</script>
{% endblock %}
